==> linglong-client-1.0.10-sources.jar: cn/com/duiba/linglong/client/WorkerSdkConfiguration.java <==
package cn.com.duiba.linglong.client;

import cn.com.duiba.linglong.client.cluster.ClusterConfiguration;
import cn.com.duiba.linglong.client.job.ScheduleProperties;
import cn.com.duiba.linglong.client.job.WorkerScheduleConfiguration;
import cn.com.duiba.linglong.client.monitor.WorkerMonitorConfiguration;
import cn.com.duiba.linglong.client.service.JobStatusManager;
import cn.com.duiba.linglong.client.service.channel.JobConsumerChannel;
import cn.com.duiba.linglong.client.service.channel.JobConsumerChannelManager;
import cn.com.duiba.linglong.client.service.logger.JobLogConfiguration;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Import;
import org.springframework.context.annotation.Scope;
import org.springframework.scheduling.annotation.EnableScheduling;

/**
 * @author liuyao
 */
@EnableScheduling
@Configuration
@Import({
        ClusterConfiguration.class,
        JobLogConfiguration.class,
        WorkerMonitorConfiguration.class,
        WorkerScheduleConfiguration.class
})
@EnableConfigurationProperties(ScheduleProperties.class)
public class WorkerSdkConfiguration {

    @Bean
    public JobStatusManager jobStatusManager(){
        return new JobStatusManager();
    }

    @Bean
    public JobConsumerChannelManager jobConsumerChannelManager(){
        return new JobConsumerChannelManager();
    }

    @Bean
    @Scope("prototype")
    public JobConsumerChannel jobConsumerChannel(){
        return new JobConsumerChannel();
    }

}

==> linglong-client-1.0.13-sources.jar: cn/com/duiba/linglong/client/WorkerSdkConfiguration.java <==
package cn.com.duiba.linglong.client;

import cn.com.duiba.linglong.client.cluster.ClusterConfiguration;
import cn.com.duiba.linglong.client.job.WorkerScheduleConfiguration;
import cn.com.duiba.linglong.client.job.WorkerScheduleProperties;
import cn.com.duiba.linglong.client.monitor.WorkerMonitorConfiguration;
import cn.com.duiba.linglong.client.service.JobStatusManager;
import cn.com.duiba.linglong.client.service.channel.JobConsumerChannel;
import cn.com.duiba.linglong.client.service.channel.JobConsumerChannelManager;
import cn.com.duiba.linglong.client.service.logger.JobLogConfiguration;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Import;
import org.springframework.context.annotation.Scope;
import org.springframework.scheduling.annotation.EnableScheduling;

/**
 * @author liuyao
 */
@EnableScheduling
@Configuration
@Import({
        ClusterConfiguration.class,
        JobLogConfiguration.class,
        WorkerMonitorConfiguration.class,
        WorkerScheduleConfiguration.class
})
@EnableConfigurationProperties(WorkerSdkProperties.class)
public class WorkerSdkConfiguration {

    @Bean
    public JobStatusManager jobStatusManager(){
        return new JobStatusManager();
    }

    @Bean
    public JobConsumerChannelManager jobConsumerChannelManager(){
        return new JobConsumerChannelManager();
    }

    @Bean
    @Scope("prototype")
    public JobConsumerChannel jobConsumerChannel(){
        return new JobConsumerChannel();
    }

}
